@@ -1,10 +1,10 @@
 import requests
-from xml.etree import ElementTree
+import json
 
 from ..utils import retry, ensure_and_log
 
 
-submit_base_url = 'https://fold.weizmann.ac.il/fldbin/findex?m=xml&sq='
+submit_base_url = 'https://fold.proteopedia.org/cgi-bin/findex?m=json&sq='
 
 
 @retry()
@@ -12,9 +12,8 @@ def submit_and_get_result(seq):
     submit_url = submit_base_url + seq
     r = requests.get(submit_url)
     r.raise_for_status()
-    tree = ElementTree.fromstring(r.text)
-    result = float(tree.find('findex').text)
-    return result
+    data = json.loads(r.text)
+    return data["findex"]
 
 
 @ensure_and_log
